"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ts = require("typescript");
const fp_1 = require("lodash/fp");
const description_generate_1 = require("./description-generate");
const utils_1 = require("./utils");
/**
 * Typescript transformer factory
 * @param program Program
 */
exports.transformer = (program) => context => file => ts.visitNode(file, visitNode(context, program.getTypeChecker()));
/**
 * Typescript AST Node visitor
 * @param context Transformation context
 * @param checker Type checker
 */
const visitNode = (context, checker) => node => {
    node = ts.visitEachChild(node, visitNode(context, checker), context);
    if (!ts.isCallExpression(node) ||
        !utils_1.isTargetExpression(node) ||
        !node.typeArguments) {
        return node;
    }
    const [typeArgument] = node.typeArguments;
    const typeTemplate = description_generate_1.generateNodeDescription(typeArgument)(checker);
    const template = fp_1.isArray(typeTemplate)
        ? ts.createArrayLiteral(typeTemplate.map(property => ts.createRegularExpressionLiteral(JSON.stringify(property))))
        : ts.createRegularExpressionLiteral(JSON.stringify(typeTemplate));
    return ts.updateCall(node, node.expression, node.typeArguments, [
        template,
        ...node.arguments,
    ]);
};
//# sourceMappingURL=transformer.js.map